References
----------

.. [Geib2019] Nils C. Geib, Matthias Zilk, Thomas Pertsch, and Falk
        Eilenberger, "Common pulse retrieval algorithm: a fast and universal
        method to retrieve ultrashort pulses," Optica 6, 495-505 (2019)
.. [Lozovoy2004] V. V. Lozovoy, I. Pastirk and M. Dantus, "Multiphoton intrapulse
        interference. IV. Ultrashort laser pulse spectral phase
        characterization and compensation," Opt. Lett. 29, 775-777
        (OSA, 2004).
.. [Xu2006] B. Xu, J. M. Gunn, J. M. D. Cruz, V. V. Lozovoy and M. Dantus,
        "Quantitative investigation of the multiphoton intrapulse
        interference phase scan method for simultaneous phase measurement
        and compensation of femtosecond laser pulses," J. Opt. Soc. Am. B
        23, 750-759 (OSA, 2006).
.. [Miranda2012a] M. Miranda, T. Fordell, C. Arnold, A. L'Huillier and H. Crespo,
        "Simultaneous compression and characterization of ultrashort laser
        pulses using chirped mirrors and glass wedges," Opt. Express 20,
        688-697 (OSA, 2012).
.. [Miranda2012b] M. Miranda, C. L. Arnold, T. Fordell, F. Silva, B. Alonso, R.
        Weigand, A. L'Huillier and H. Crespo, "Characterization of
        broadband few-cycle laser pulses with the d-scan technique," Opt.
        Express 20, 18732-18743 (OSA, 2012).        
.. [Kane1993] D. J. Kane and R. Trebino, "Characterization of arbitrary
        femtosecond pulses using frequency-resolved optical gating," IEEE
        J. Quant. Electron. 29, 571-579 (IEEE, 1993).
.. [Kane1999] D. J. Kane, "Recent progress toward real-time measurement of
       ultrashort laser pulses," IEEE J. Quant. Electron. 35, 421-431
       (IEEE, 1999).        
.. [Trebino2000] R. Trebino, "Frequency-Resolved Optical Gating: The Measurement of
        Ultrashort Laser Pulses," , (Springer US, 2000).        
.. [Witting2016] T. Witting, D. Greening, D. Walke, P. Matia-Hernando, T. Barillot,
        J. P. Marangos and J. W. G. Tisch, "Time-domain ptychography of
        over-octave-spanning laser pulses in the single-cycle regime," Opt.
        Lett. 41, 4218-4221 (OSA, 2016).
.. [Dorrer2002] C. Dorrer and I. A. Walmsley, "Accuracy criterion for ultrashort
        pulse characterization techniques: application to spectral phase
        interferometry for direct electric field reconstruction," J. Opt.
        Soc. Am. B 19, 1019-1029 (OSA, 2002).
.. [Briggs1995] W. L. Briggs and v. E. Henson, "The DFT: an owners' manual for the
       discrete Fourier transform," (SIAM, 1995).
.. [Hansen2014] E. W. Hansen, "Fourier transforms: principles and applications," (John
       Wiley & Sons, 2014).
.. [Trefethen2014] L. N. Trefethen and J. A. C. Weideman, "The exponentially convergent
       trapezoidal rule," SIAM Review 56, 385-458 (2014).        
.. [DispersionFormulas] http://refractiveindex.info/database/doc/Dispersion%20formulas.pdf
.. [Sidorenko2016] P. Sidorenko, O. Lahav, Z. Avnat and O. Cohen, "Ptychographic
        reconstruction algorithm for frequency-resolved optical gating:
        super-resolution and supreme robustness," Optica 3, 1320-1330 (OSA,
        2016).
.. [Sidorenko2017] P. Sidorenko, O. Lahav, Z. Avnat and O. Cohen, "Ptychographic
        reconstruction algorithm for frequency resolved optical gating:
        super-resolution and extreme robustness: erratum," Optica 4,
        1388-1389 (OSA, 2017).
.. [Miranda2017] M. Miranda, J. Penedones, C. Guo, A. Harth, M. Louisy, L. Neoričić,
        A. L'Huillier and C. L. Arnold, "Fast iterative retrieval algorithm
        for ultrashort pulse characterization using dispersion scans," J.
        Opt. Soc. Am. B 34, 190-197 (OSA, 2017).
.. [DeLong1994] K. W. DeLong, B. Kohler, K. Wilson, D. N. Fittinghoff and R.
        Trebino, "Pulse retrieval in frequency-resolved optical gating
        based on the method of generalized projections," Opt. Lett. 19,
        2152-2154 (Optical Society of America, 1994)
.. [Escoto2018] E. Escoto, A. Tajalli, T. Nagy and G. Steinmeyer, "Advanced phase
        retrieval for dispersion scan: a comparative study," J. Opt. Soc.
        Am. B 35, 8-19 (OSA, 2018).
.. [Diels2006] J.-C. Diels and W. Rudolph, "Ultrashort laser pulse phenomena,"
    2nd ed. (Academic press, 2006)